aboutsummaryrefslogtreecommitdiffstats
path: root/scalding/src/test/scala/sandcrawler/ScoreJobTest.scala
diff options
context:
space:
mode:
Diffstat (limited to 'scalding/src/test/scala/sandcrawler/ScoreJobTest.scala')
-rw-r--r--scalding/src/test/scala/sandcrawler/ScoreJobTest.scala32
1 files changed, 16 insertions, 16 deletions
diff --git a/scalding/src/test/scala/sandcrawler/ScoreJobTest.scala b/scalding/src/test/scala/sandcrawler/ScoreJobTest.scala
index 54ae801..f92ba31 100644
--- a/scalding/src/test/scala/sandcrawler/ScoreJobTest.scala
+++ b/scalding/src/test/scala/sandcrawler/ScoreJobTest.scala
@@ -121,7 +121,7 @@ class ScoreJobTest extends FlatSpec with Matchers {
val CrossrefStringWithoutTitle = CrossrefString.replace("title", "nottitle")
val MalformedCrossrefString = CrossrefString.replace("}", "")
val CrossrefStrings = List(
- CrossrefString.replace("<<TITLE>>", "Title 1: TNG").replace("<<DOI>>", "DOI-0"),
+ CrossrefString.replace("<<TITLE>>", "Title 2: TNG").replace("<<DOI>>", "DOI-0"),
CrossrefString.replace("<<TITLE>>", "Title 1: TNG 2A").replace("<<DOI>>", "DOI-0.5"),
CrossrefString.replace("<<TITLE>>", "Title 1: TNG 3").replace("<<DOI>>", "DOI-0.75"),
CrossrefString.replace("<<TITLE>>", "Title 2: Rebooted").replace("<<DOI>>", "DOI-1"))
@@ -182,24 +182,24 @@ class ScoreJobTest extends FlatSpec with Matchers {
.sink[(String, Int, String, String)](TypedTsv[(String, Int, String, String)](output)) {
// Grobid titles and slugs (in parentheses):
// Title 1 (title1)
// Title 2: TNG (title2)
// Title 3: The Sequel (title3)
// crossref titles and slugs (in parentheses):
// Title 1: TNG (title1)
// Title 1: TNG 2A (title1)
// Title 1: TNG 3 (title1)
// Title 2: Rebooted (title2)
// Join should have 3 "title1" slugs and 1 "title2" slug
outputBuffer =>
- "The pipeline" should "return a 4-element list" in {
- outputBuffer should have length 4
+ "The pipeline" should "return a 1-element list" in {
+ outputBuffer should have length 1
}
it should "has right # of entries with each slug" in {
val slugs = outputBuffer.map(_._1)
val countMap : Map[String, Int] = slugs.groupBy(identity).mapValues(_.size)
- countMap("title1") shouldBe 3
- countMap("title2") shouldBe 1
+ // XXX: countMap("title1") shouldBe 3
+ countMap("title2tng") shouldBe 1
}
def bundle(slug : String, grobidIndex : Int, crossrefIndex : Int) : (String, Int, String, String) = {
@@ -215,10 +215,10 @@ class ScoreJobTest extends FlatSpec with Matchers {
}
it should "have right output values" in {
- outputBuffer.exists(_ == bundle("title1", 0, 0))
- outputBuffer.exists(_ == bundle("title1", 0, 2))
- outputBuffer.exists(_ == bundle("title1", 0, 1))
- outputBuffer.exists(_ == bundle("title2", 1, 3))
+ //outputBuffer.exists(_ == bundle("title1", 0, 0))
+ //outputBuffer.exists(_ == bundle("title1", 0, 2))
+ //outputBuffer.exists(_ == bundle("title1", 0, 1))
+ outputBuffer.exists(_ == bundle("title2tng", 1, 3))
}
}
.run
@@ -182,24 +182,24 @@ class ScoreJobTest extends FlatSpec with Matchers {
// Grobid titles and slugs (in parentheses):
// Title 1 (title1)
- // Title 2: TNG (title2)
- // Title 3: The Sequel (title3)
+ // Title 2: TNG (title2tng)
+ // Title 3: The Sequel (title3thesequel)
// crossref titles and slugs (in parentheses):
@@ -182,24 +182,24 @@ class ScoreJobTest extends FlatSpec with Matchers {
// crossref titles and slugs (in parentheses):
- // Title 1: TNG (title1)
- // Title 1: TNG 2A (title1)
- // Title 1: TNG 3 (title1)
- // Title 2: Rebooted (title2)
- // Join should have 3 "title1" slugs and 1 "title2" slug
+ // Title 2: TNG (title2tng)
+ // Title 1: TNG 2A (title1tng2a)
+ // Title 1: TNG 3 (title1tng3)
+ // Title 2: Rebooted (title2rebooted)
+ // XXX: Join should have 3 "title1" slugs and 1 "title2tng" slug
outputBuffer =>